@@ -3,30 +3,37 @@
 
 =for abstract Basic FLTK::MenuBar Example
 
-=for license Artistic License 2.0 | Copyright (C) 2009 by Sanko Robinson
+=for license Artistic License 2.0 | Copyright (C) 2009,2010 by Sanko Robinson
 
 =for author Sanko Robinson <sanko@cpan.org> - http://sankorobinson.com/
 
-=for git $Id: menubar.pl 848cb11 2009-10-04 15:26:46Z sanko@cpan.org $
+=for git $Id: menubar.pl 4d25a1c 2010-09-17 21:36:13Z sanko@cpan.org $
+
+=for todo expand into a full text editor
 
 =cut
 
 use strict;
 use warnings;
 use FLTK;
+use Data::Dumper;
 $|++;
 
 #
-my $win = new FLTK::Window(500, 500, 'Test');
+my $win = new FLTK::Window(500, 21, 'Test');
 $win->begin;
 my $m = FLTK::MenuBar->new(0, 0, 660, 21, 'Test');
+{
+
+    package FLTKx::MyItem;
+    our @ISA = qw[FLTK::Item];
+}
 build_menus($m, $win);
 {
-    use Data::Dump;
-    sub test { warn 'Click 2'; dd \@_ }
+    sub test { warn 'Click 2'; warn Dumper \@_ }
     my $XXXXX = 100;
     $m->add('This/is/a/te\/st', 0,
-            sub { warn 'Click 1'; dd \@_; },
+            sub { warn 'Click 1'; warn Dumper \@_; },
             [qw'X fsaf', $XXXXX]);
     $m->add('This/is/a/test', 0, \&test);
 
@@ -34,10 +41,9 @@ build_menus($m, $win);
     $m->add_many('This|is|n/o/t/h|er|test');
     $XXXXX = 2;
 }
-my $mb = FLTK::MultiBrowser->new(0, 20, 100, 100);
 $win->end();
 $win->show();
-run;
+FLTK::run;
 
 sub build_menus {
     my ($menu) = @_;
@@ -45,15 +51,14 @@ sub build_menus {
     $menu->begin();
     $g = FLTK::ItemGroup->new("&File");
     $g->begin();
-    FLTK::Item->new(
+    FLTKx::MyItem->new(
         "&New File",
         0,
         sub {
             warn 'New File';
-            use Data::Dump;
-            dd $_[0];
-            $m->item(shift);
-            dd $m->item;
+            warn Dumper \@_;
+            $m->item(@_);
+            warn Dumper $m->item;
         }
     );
     FLTK::Item->new(
@@ -83,14 +88,14 @@ sub build_menus {
                     FLTK::ACCELERATOR + ord 'v',
                     sub { warn 'view_cb' }, 0);
     my $item = FLTK::Item->new("&Close View");
-    $item->callback(sub { warn 'close_cb'; use Data::Dump; dd \@_ });
+    $item->callback(sub { warn 'close_cb'; warn Dumper \@_ });
     new FLTK::Divider();
     {
         my $x = FLTK::ItemGroup->new('Submenu');
         $x->begin();
         my $btn = FLTK::Button->new(0, 0, 250, 20, 'Button');
         $btn->callback(sub { warn 'button'; warn ref shift });
-        $btn->labelfont(HELVETICA_BOLD);
+        $btn->labelfont(FLTK::HELVETICA_BOLD);
         $x->end();
     }
     new FLTK::Divider();
